summaryrefslogtreecommitdiff
path: root/core/arch/arm/kernel/spin_lock_debug.c
diff options
context:
space:
mode:
Diffstat (limited to 'core/arch/arm/kernel/spin_lock_debug.c')
-rw-r--r--core/arch/arm/kernel/spin_lock_debug.c5
1 files changed, 3 insertions, 2 deletions
diff --git a/core/arch/arm/kernel/spin_lock_debug.c b/core/arch/arm/kernel/spin_lock_debug.c
index 2a450a5..00a2a00 100644
--- a/core/arch/arm/kernel/spin_lock_debug.c
+++ b/core/arch/arm/kernel/spin_lock_debug.c
@@ -49,10 +49,11 @@ bool have_spinlock(void)
{
struct thread_core_local *l;
- if (!thread_irq_disabled()) {
+ if (!thread_foreign_intr_disabled()) {
/*
* Normally we can't be holding a spinlock since doing so would
* imply IRQ are disabled (or the spinlock logic is flawed).
*/
return false;
}
@@ -49,10 +49,11 @@ bool have_spinlock(void)
/*
* Normally we can't be holding a spinlock since doing so would
- * imply IRQ are disabled (or the spinlock logic is flawed).
+ * imply foreign interrupts are disabled (or the spinlock
+ * logic is flawed).
*/
return false;